#include <mysql.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

MYSQL *mysql;

void die_unless(int rc)
{
  if (! rc)
  {
    printf("An error occurred, exiting...\n");
    if (mysql)
    {
      printf("Error: %d, %s\n", mysql_errno(mysql), mysql_error(mysql));
      mysql_close(mysql);
    }
    exit(0);
  }
}

void check_stmt(int rc, MYSQL_STMT *stmt)
{
  if (rc)
  {
    printf("An error occurred, exiting...\n");
    if (stmt)
    {
      printf("Error: %d, %s\n", mysql_stmt_errno(stmt),
                                mysql_stmt_error(stmt));
    }
    if (mysql)
      mysql_close(mysql);
    exit(0);
  }
}

int main(int argc, char *argv[])
{
  const int ITERATION_COUNT= 1000000;
  const char stmt_text[]= "select deliv_status_cd from mail_log where "
                          "email = ? and email_content_id = ?";
  MYSQL_STMT *stmt;
  MYSQL_BIND bind[2];
  const char mail_data[]= "mail@sqa.org.uk";
  const int id_data= 535822;
  int i, rc;

  mysql= mysql_init(0);
  rc= 0 == mysql_real_connect(mysql, "192.168.1.102", "es_app",
                              "blabla", "es", 3307, 0, 0);
  die_unless(rc == 0);

  stmt= mysql_stmt_init(mysql);
  rc= mysql_stmt_prepare(stmt, stmt_text, sizeof(stmt_text));
  check_stmt(rc, stmt);
  memset(bind, 0, sizeof(bind));
  bind[0].buffer_type= MYSQL_TYPE_STRING;
  bind[0].buffer= (void*) mail_data;
  bind[0].buffer_length= sizeof(mail_data);
  bind[1].buffer_type= MYSQL_TYPE_LONG;
  bind[1].buffer= (void*) &id_data;

  die_unless(mysql_stmt_param_count(stmt) == 2);
  rc= mysql_stmt_bind_param(stmt, bind);
  check_stmt(rc, stmt);

  printf("%s: successfully connected, running the loop\n", argv[0]);
  for (i= 0; i < ITERATION_COUNT; ++i)
  {
    rc= mysql_stmt_execute(stmt);
    check_stmt(rc, stmt);
  }

  mysql_stmt_close(stmt);
  mysql_close(mysql);
}
